@@ -17,9 +17,10 @@ import os
 
 
 def render_template(template_name):
-    root = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
+    root = os.path.abspath(os.path.dirname(__file__))
+    root = os.path.abspath(os.path.dirname(root))
     p = os.path.join(root, "templates", f"{template_name}.template")
-    print(p)
+    print(p, 'asdfs')
     if os.path.isfile(p):
         with open(p, "r") as rfile:
             txt = rfile.read()
